#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the DeepRoute dataset."""

from tensorbay.opendataset.DeepRoute.loader import DeepRoute

__all__ = ["DeepRoute"]
